* Do file for reproducing cross country figures in paper / appendix

use "xxxxx"

* Reproducing figures
****
/* 
The general method to reproduce figures where we want to annotate on US and IRE, is to plot binscatters for all countries excluding the US and Ireland.
Then to export the binscattered datapoints to excel, and then to include US and IRE in the series when plotting a line of best fit. The slope coefficient should
be the same as in the analagous regression, but including US and IRE. For graphs where we don't want to annotate, just binscatter on whole sample.
*/


* Figure 2 - DI equity differential and corporate tax rates
binscatter nomreturn_differential_DI_e comb_citrate if subsample2==1 & countryname != "Turkey" & countryname != "Slovak Republic" & countryname != "United States" ///
 & countryname != "Ireland" ,  nquantiles(14) mcolor(gs2) graphregion(color(white)) ///
ytitle("Percentage Points") xtitle("Corporate Tax Rate") ///
legend(off) graphregion(lwidth(none)) savedata ("/Users/tomwright/Documents/thesis/Thesis contd/paper/diequitybinsc") replace

reg nomreturn_differential_DI_e comb_citrate if subsample2==1 & countryname != "Turkey" & countryname != "Slovak Republic", vce(cluster countryname)

* Figure 2.b - DI equity differential and corporate tax rates, conditional
binscatter nomreturn_differential_DI_e comb_citrate if subsample2==1 & countryname != "Turkey" & countryname != "Slovak Republic", ///
controls(nomreturn_differential_PI_e EU gdppc) mcolor(gs2) graphregion(color(white)) ///
ytitle("Percentage Points") xtitle("Corporate Tax Rate") ///
legend(off) graphregion(lwidth(none)) savedata ("/Users/tomwright/Documents/thesis/Thesis contd/paper/diequitybinsccond") replace

reg nomreturn_differential_DI_e comb_citrate nomreturn_differential_PI_e EU gdppc if subsample2==1 & countryname != "Turkey" & countryname != "Slovak Republic", vce(cluster countryname)

* Figure 3.a - DI equity liability returns and corporate tax rate
binscatter nomreturn_ilde_bp6_usd comb_citrate if subsample2==1 & countryname != "Japan" & countryname != "New Zealand" & countryname != "Turkey" ///
& countryname != "Slovak Republic" & countryname != "United States" & countryname != "Ireland", mcolor(gs2) graphregion(color(white)) ///
ytitle("Percentage Points") xtitle("Corporate Tax Rate") ///
legend(off) graphregion(lwidth(none)) savedata ("/Users/tomwright/Documents/thesis/Thesis contd/paper/dielbinsc") replace
* see appendix for justification of sample - Japan and New Zealand have implausibly large returns to liabilities.

reg nomreturn_ilde_bp6_usd comb_citrate if subsample2==1 & countryname != "Japan" & countryname != "New Zealand" & countryname != "Turkey" ///
& countryname != "Slovak Republic", vce(cluster countryname)


* Figure 3.b - DI equity liability returns and corporate tax rate, before and after tax
* After tax on BEA reporting countries
binscatter nomreturn_ilde_bp6_usd comb_citrate if subsample2a==1 & countryname != "Japan" & countryname != "New Zealand" & countryname != "Slovak Republic" & countryname != "Turkey" ///
& countryname != "United States" & countryname != "Ireland", mcolor(gs2) graphregion(color(white)) ///
ytitle("Percentage Points") xtitle("Corporate Tax Rate") ///
legend(off) graphregion(lwidth(none)) savedata ("/Users/tomwright/Documents/thesis/Thesis contd/paper/dielnetBEAbinsc") replace
* Before tax on BEA reporting countries
binscatter nomreturn_ilde_bp6_usd_crct comb_citrate if subsample2a==1 & countryname != "Japan" & countryname != "New Zealand" & countryname != "Slovak Republic" & countryname != "Turkey" ///
& countryname != "United States" & countryname != "Ireland", mcolor(gs2) graphregion(color(white)) ///
ytitle("Percentage Points") xtitle("Corporate Tax Rate") ///
legend(off) graphregion(lwidth(none)) savedata ("/Users/tomwright/Documents/thesis/Thesis contd/paper/dielgrossBEAbinsc") replace
	*combine binscattered values to make overlayed figure.

* Figure 3.c - DI equity asset returns and corporate tax rate
binscatter nomreturn_iade_bp6_usd comb_citrate if subsample2==1 & countryname != "Turkey" ///
& countryname != "Slovak Republic" & countryname != "United States" & countryname != "Ireland", mcolor(gs2) graphregion(color(white)) ///
ytitle("Percentage Points") xtitle("Corporate Tax Rate") ///
legend(off) graphregion(lwidth(none)) savedata ("/Users/tomwright/Documents/thesis/Thesis contd/paper/dielbinsc") replace
